@@ -1,4 +1,4 @@
-'tldextract helpers for testing and fetching remote resources.'
+"tldextract helpers for testing and fetching remote resources."
 
 import re
 import socket
@@ -7,12 +7,14 @@ from urllib.parse import scheme_chars
 
 
 IP_RE = re.compile(
-    r'^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$')  # pylint: disable=line-too-long
+    # pylint: disable-next=line-too-long
+    r"^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$"
+)
 
-SCHEME_RE = re.compile(r'^([' + scheme_chars + ']+:)?//')
+SCHEME_RE = re.compile(r"^([" + scheme_chars + "]+:)?//")
 
 
-def looks_like_ip(maybe_ip):
+def looks_like_ip(maybe_ip: str) -> bool:
     """Does the given str look like an IP address?"""
     if not maybe_ip[0].isdigit():
         return False
@@ -23,5 +25,7 @@ def looks_like_ip(maybe_ip):
     except (AttributeError, UnicodeError):
         if IP_RE.match(maybe_ip):
             return True
-    except socket.error:
-        return False
+    except OSError:
+        pass
+
+    return False
